<?php

/**
 * @file
 * Contains \Drupal\smsmsg91\Form\SMSSendingForm.
 */

namespace Drupal\smsmsg91\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Implements a SMS Sending Form.
 */
class SMSSendingForm extends FormBase {

  /**
   * {@inheritdoc}.
   */
  public function getFormId() {
    return 'smssendingform';
  }

  /**
   * {@inheritdoc}.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
  
  $form = array();
  $form['mobile_number'] = array(
    '#type' => 'textfield', 
    '#title' => 'Mobile Number',
    '#size' => 20,
    '#maxlength' => 150,
    '#required' => TRUE,  
  );

  $form['sms_message'] = array(
    '#type' => 'textarea', 
    '#title' => 'Message',
    '#size' => 256,
    '#maxlength' => 256,
    '#required' => FALSE,  
  );

  $form['submit_button'] = array(
    '#type' => 'submit',
    '#value' => t('Send SMS Now'),
  ); 

  return $form;
}
   

  /**
   * {@inheritdoc}
   */

public function validateForm(array &$form, FormStateInterface $form_state)
{
  $mobile = $form_state->getValue('mobile_number');
  if (!is_numeric($mobile)) {
    form_set_error('mobile_number', t('Please Enter a Valid Mobile Number'));
  }
}

  /**
   * {@inheritdoc}
   */

public function submitForm(array &$form, FormStateInterface $form_state) 
{
  $config = \Drupal::config('smsmsg91.settings');
  $mobile = $form_state->getValue('mobile_number');
  $sms_message = $form_state->getValue('sms_message');
  
  /*Send SMS using PHP*/    
    
    //This will be set up from Settings variables.
    $authKey = $config->get('smsmsg91_authKey');

    //Multiple mobiles numbers separated by comma
    $mobileNumber = $mobile;
    
    //Sender ID,While using route4 sender id should be 6 characters long.To be set up in settings variables.
    $senderId = $config->get('smsmsg91_senderID');
    
    //Your message to send, Add URL encoding here.
    $message = urlencode($sms_message);
  
    
    //Define route 
    $route = $config->get('smsmsg91_route');
    //Prepare you post parameters
    $postData = array(
        'authkey' => $authKey,
        'mobiles' => $mobileNumber,
        'message' => $message,
        'sender' => $senderId,
        'route' => $route
    );
    
    //API URL
    $url="https://control.msg91.com/api/sendhttp.php";
    
    // init the resource
    $ch = curl_init();
    curl_setopt_array($ch, array(
        CURLOPT_URL => $url,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_POST => true,
        CURLOPT_POSTFIELDS => $postData
        //,CURLOPT_FOLLOWLOCATION => true
    ));


    //Ignore SSL certificate verification
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

    
    //get response
    $output = curl_exec($ch);

    //Print error if any
    if(curl_errno($ch))
    {
        echo 'error:' . curl_error($ch);
    }
    
    curl_close($ch);

   echo $output;

   drupal_set_message('SMS Sent');  
	    	
}

}
